LogbotClient class

Constructors

LogbotClient()
factory

Properties

authenticator → LogbotHttpBearerAuth
Return the access token function to be used by other openapi http clients for the bearer token authentication
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

login(LogbotCredentials credentials, {String? otp}) → Future<AuthenticationResponse?>
Log in with a user, saves the credentials and tokens on the client to refresh the access later
logout() → void
Delete the user credentials from the client to log out the user
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
whoAmI() → String?
Returns the current logged in user

Operators

operator ==(Object other) → bool
The equality operator.
inherited