LogbotCredentials class

Constructors

LogbotCredentials({required String clientId, required String clientSecret, required String username, required String password, String? basePath})
LogbotCredentials.fromJson(dynamic json)

Properties

basePath ↔ String?
latefinal
clientId ↔ String
latefinal
clientSecret ↔ String
latefinal
hashCode → int
The hash code for this object.
no setterinherited
password ↔ String
latefinal
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
username ↔ String
latefinal

Methods

copyWith({String? clientId, String? clientSecret, String? username, String? password, String? basePath}) → LogbotCredentials
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited